@@ -2,8 +2,11 @@ import argparse
 import subprocess
 from pathlib import Path
 import shutil
+import secrets
 
-REPO_URL = "https://github.com/Tobi-De/fuzzy-couscous"
+
+def get_repo_url(repo: str, branch: str):
+    return f"https://github.com/{repo}/archive/{branch}.zip"
 
 
 def cli():
@@ -18,9 +21,9 @@ def cli():
     )
     parser.add_argument("project_name")
     parser.add_argument("-b", "--branch", default="main")
+    parser.add_argument("-r", "--repo", default="Tobi-De/fuzzy-couscous")
     args = parser.parse_args()
 
-    url = REPO_URL + f"/archive/{args.branch}.zip"
     project_name = args.project_name.strip().replace(" ", "_")
 
     # run the django-admin command
@@ -30,7 +33,7 @@ def cli():
             "startproject",
             project_name,
             "--template",
-            url,
+            get_repo_url(args.repo, args.branch),
             "-e=py,html,toml,md",
         ]
     )
@@ -45,5 +48,13 @@ def cli():
     new_project_dir = Path() / project_name
     shutil.move(project_dir, new_project_dir)
 
+    # create a .env file
+    env_file = new_project_dir / ".env"
+    env_file.write_text(
+        f"DJANGO_SECRET_KEY={secrets.token_urlsafe(32)}\n"
+        "DJANGO_ALLOWED_HOSTS=*\n"
+        f"DATABASE_URL=postgres:///{project_name}"
+    )
+
     # delete the root dir
     shutil.rmtree(project_root_new_dir)
